@@ -16,6 +16,8 @@ class Page(Orderable, Displayable):
         related_name="children")
     titles = models.CharField(editable=False, max_length=1000, null=True)
     content_model = models.CharField(editable=False, max_length=50, null=True)
+    login_required = models.BooleanField(_("Login required"), 
+        help_text=_("If checked, only logged in users can view this page"))
 
     class Meta:
         verbose_name = _("Page")
